@@ -10,7 +10,7 @@ class WindyGridWorld(GridWorld):
 					   world_height=7, 
 					   unit_pixel=40,
 					   default_reward=-1,
-					   goal_reward=100,
+					   goal_reward=-1,
 					   punish_reward=-10,
 					   windy = True):
 		super().__init__(world_width, 
@@ -49,4 +49,4 @@ if __name__ == '__main__':
 				time.sleep(1.0)
 				break
 	env.close()
-	print("env closed")
\ No newline at end of file
+	print("env closed")
